@@ -1764,7 +1764,7 @@ listener_dbus_filter_function (DBusConnection *connection,
         dbus_connection_unref (connection);
         listener->priv->connection = NULL;
 
-        g_timeout_add (10000, (GSourceFunc)reinit_dbus, listener);
+        g_timeout_add_seconds (10, (GSourceFunc)reinit_dbus, listener);
     } else if (dbus_message_is_signal (message,
                                      DBUS_INTERFACE_DBUS,
                                      "NameOwnerChanged")) {
@@ -1795,7 +1795,7 @@ listener_dbus_system_filter_function (DBusConnection *connection,
         dbus_connection_unref (connection);
         listener->priv->system_connection = NULL;
 
-        g_timeout_add (10000, (GSourceFunc)reinit_dbus, listener);
+        g_timeout_add_seconds (10, (GSourceFunc)reinit_dbus, listener);
     } else {
         return listener_dbus_handle_system_message (connection, message, user_data, FALSE);
     }
@@ -2196,7 +2196,7 @@ gs_listener_init (GSListener *listener) {
 #endif
     listener->priv->prefs = gs_prefs_new();
 
-    gs_listener_dbus_init (listener);
+    g_assert (gs_listener_dbus_init (listener));
 
     init_session_id (listener);
 
