@@ -341,7 +341,7 @@ remove_lock_timer (GSManager *manager) {
 
 static void
 add_lock_timer (GSManager *manager,
-                glong      timeout) {
+                glong      seconds) {
     if (!manager->priv->prefs->lock_enabled)
         return;
     if (!manager->priv->prefs->lock_with_saver_enabled)
@@ -349,8 +349,8 @@ add_lock_timer (GSManager *manager,
     if (manager->priv->lock_active)
         return;
 
-    gs_debug ("Scheduling screen lock after screensaver is idling for %i sec", timeout);
-    manager->priv->lock_timeout_id = g_timeout_add (timeout * 60000,
+    gs_debug ("Scheduling screen lock after screensaver is idling for %i sec", seconds * 60);
+    manager->priv->lock_timeout_id = g_timeout_add_seconds (seconds * 60,
                                                     (GSourceFunc)activate_lock_timeout,
                                                     manager);
 }
@@ -413,8 +413,8 @@ remove_cycle_timer (GSManager *manager) {
 
 static void
 add_cycle_timer (GSManager *manager,
-                 glong      timeout) {
-    manager->priv->cycle_timeout_id = g_timeout_add (timeout,
+                 glong      seconds) {
+    manager->priv->cycle_timeout_id = g_timeout_add_seconds (seconds,
                                                      (GSourceFunc)cycle_timeout,
                                                      manager);
 }
@@ -564,7 +564,7 @@ activate_dpms_timeout (GSManager *manager) {
                     gs_debug("DPMS: On -> Standby");
                     DPMSForceLevel (gdk_x11_get_default_xdisplay(), DPMSModeStandby);
                     remove_dpms_timer (manager);
-                    add_dpms_timer (manager, manager->priv->prefs->dpms_off_timeout);
+                    add_dpms_timer (manager, manager->priv->prefs->dpms_off_timeout * 60);
                     return FALSE;
                 } else if (power_level == DPMSModeStandby || power_level == DPMSModeSuspend) {
                     gs_debug("DPMS: %s -> Off", power_level == DPMSModeStandby ? "Standby" : "Suspend");
@@ -595,8 +595,8 @@ add_dpms_timer (GSManager *manager,
     if (timeout == 0)
         return;
 
-    gs_debug ("Scheduling DPMS change after screensaver is idling for %i minute(s)", timeout);
-    manager->priv->dpms_timeout_id = g_timeout_add (timeout * 60000,
+    gs_debug ("Scheduling DPMS change after screensaver is idling for %i seconds(s)", timeout);
+    manager->priv->dpms_timeout_id = g_timeout_add_seconds (timeout,
                                                     (GSourceFunc)activate_dpms_timeout,
                                                     manager);
 }
@@ -777,7 +777,7 @@ deepsleep_idle (GSManager *manager) {
 static void
 add_deepsleep_idle (GSManager *manager) {
     remove_deepsleep_idle(manager);
-    manager->priv->deepsleep_idle_id = g_timeout_add (15000, (GSourceFunc)deepsleep_idle, manager);
+    manager->priv->deepsleep_idle_id = g_timeout_add_seconds (15, (GSourceFunc)deepsleep_idle, manager);
 }
 
 static gboolean
@@ -802,7 +802,7 @@ manager_show_window (GSManager *manager,
     remove_lock_timer (manager);
     add_lock_timer (manager, manager->priv->prefs->lock_timeout);
 
-    if (manager->priv->prefs->cycle >= 10000) {
+    if (manager->priv->prefs->cycle >= 10) {
         remove_cycle_timer (manager);
         add_cycle_timer (manager, manager->priv->prefs->cycle);
     }
@@ -1072,7 +1072,7 @@ reconfigure_monitors (GdkDisplay *display,
 
     gs_manager_request_unlock (manager);
 
-    g_timeout_add (2000,
+    g_timeout_add_seconds (2,
                    (GSourceFunc)remove_overlays,
                    windows);
 }
@@ -1271,7 +1271,7 @@ gs_manager_activate (GSManager *manager) {
 
     show_windows (manager->priv->windows);
 
-    g_timeout_add (2000,
+    g_timeout_add_seconds (2,
                    (GSourceFunc)remove_overlays,
                    windows);
 
